@@ -33,9 +33,11 @@ class Arirang
         res = arisend(chunk)
         buf = res.split("\r\n")[0]
         if buf != "HTTP\/1.1 400 Bad Request"
-            puts "#{$ari_host} - apache chunked handling vulnerability found !!!"
+            z = "#{$ari_host} - apache chunked handling vulnerability found !!! \n"
+            ariprint(z)
         elsif buf == "HTTP\/1.1 400 Bad Request"
-            puts "#{$ari_host} - apache chunked handling vulnerability not affected !!!"
+            z = "#{$ari_host} - apache chunked handling vulnerability not affected !!! \n"
+            ariprint(z)
         end
     end
 
