@@ -21,7 +21,7 @@ class Arirang
          buf  = "GET http://#{$ari_host}/ HTTP/1.1\r\n"
          buf += "Host: #{$ari_host}\r\n\r\n"
          response = arisend(buf)
-         response.each do |line|
+         response.each_line do |line|
          x = line.match(/^Server\: (.+)\r/)
             if x != nil
                 y = "#{$ari_host} - #{$ari_sport}/tcp - #{x[1]}\n"
